@@ -1,18 +1,22 @@
 package Dist::Zilla::Plugin::ManifestInRoot;
 
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 2 $ =~ /\d+/gmx );
 
 use Moose;
 use Dist::Zilla::File::FromCode;
-use English                 qw( -no_match_vars );
-use File::Copy              qw( copy );
-use File::Spec::Functions   qw( catfile );
+use Path::Tiny qw( path );
 
 with 'Dist::Zilla::Role::AfterBuild';
 with 'Dist::Zilla::Role::BeforeBuild';
 with 'Dist::Zilla::Role::FileGatherer';
 
+# Public attributes
+has 'excludes' => is => 'ro', traits => [ 'Array' ],
+   default     => sub { [ qw( LICENSE META.json META.yml README SIGNATURE
+                              t/00report-metadata.dd t/00report-metadata.t ) ]},
+   handles     => { 'excluding' => 'elements', }, init_arg => 'exclude';
+
 # Private functions
 my $_fix_filename = sub {
    my $name = shift; $name =~ m{ [ \'\\] }mx or return $name;
@@ -26,8 +30,13 @@ my $_fix_filename = sub {
 sub after_build {
    my ($self, $args) = @_;
 
-   copy( catfile( $args->{build_root}, 'MANIFEST' ),
-             $self->zilla->root->file( 'MANIFEST' ) );
+   my $excluding = join '|', $self->excluding;
+   my $from      = path( $args->{build_root}, 'MANIFEST' );
+   my @lines     = grep { not m{ \A (?: $excluding ) \z }mx }
+                   $from->lines( { chomp => 1 } );
+   my $to        = path( $self->zilla->root, 'MANIFEST' );
+
+   $to->spew( map { "${_}\n" } @lines );
 
    return;
 }
@@ -51,13 +60,17 @@ sub gather_files {
    return;
 }
 
+sub mvp_multivalue_args {
+   return qw( exclude );
+}
+
 1;
 
 __END__
 
 =pod
 
-=encoding utf8
+=encoding utf-8
 
 =begin html
 
@@ -78,22 +91,33 @@ Dist::Zilla::Plugin::ManifestInRoot - Puts the MANIFEST file in the project root
 
 =head1 Version
 
-This documents version v0.7.$Rev: 1 $ of L<Dist::Zilla::Plugin::ManifestInRoot>
+This documents version v0.8.$Rev: 2 $ of L<Dist::Zilla::Plugin::ManifestInRoot>
 
 =head1 Description
 
 Puts the F<MANIFEST> file in the project root so that it can be used by
-other programs, e.g. C<module_provision update_version 0.1 0.2>
+other programs, e.g. L<App::Cpanminus> and L<Module::Provision>
 
 =head1 Configuration and Environment
 
-None
+Defined these attributes;
+
+=over 3
+
+=item C<excludes>
+
+An array reference of file names to exclude from the root directory copy of the
+manifest.  Set using the multivalued initialisation argument C<exclude>.
+Defaults to the list of files generated by the build process
+
+=back
 
 =head1 Subroutines/Methods
 
 =head2 after_build
 
-Copy the F<MANIFEST> file from the build directory to the project root
+Copy the F<MANIFEST> file from the build directory to the project root filtering
+out unwanted files
 
 =head2 before_build
 
@@ -103,6 +127,11 @@ Delete the existing F<MANIFEST> file
 
 Create the content providing callback
 
+=head2 C<mvp_multivalue_args>
+
+Returns a list of configuration attribute names that are treated as
+multi valued
+
 =head1 Diagnostics
 
 None
